@@ -771,6 +771,7 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
         
     import numpy as np
     import matplotlib.pyplot as plt
+    import pyratlib as rat
 
     ax = kwargs.get('ax')
     start= kwargs.get('start')
@@ -852,7 +853,7 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
         plt.yticks(fontsize = fontsize*0.8)
       
         for i in range(0,len(tailY),step):
-            DrawLine(tailX[i], tailY[i], (rad[i]), ax = ax,arrow_color = arrow_color)
+            rat.DrawLine(tailX[i], tailY[i], (rad[i]), ax = ax,arrow_color = arrow_color)
 
         plt.plot([esquerda,esquerda] , [baixo,cima],"k")
         plt.plot([esquerda,direita]  , [cima,cima],"k")
@@ -867,7 +868,7 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
     else:
         ax.set_aspect('equal')
         for i in range(0,len(tailY),step):
-            DrawLine(tailX[i], tailY[i], (rad[i]), ax =ax,arrow_color = arrow_color)
+            rat.DrawLine(tailX[i], tailY[i], (rad[i]), ax =ax,arrow_color = arrow_color)
         ax.plot([esquerda,esquerda] , [baixo,cima],"k")
         ax.plot([esquerda,direita]  , [cima,cima],"k")
         ax.plot([direita,direita]   , [cima,baixo],"k")
